# vim:et:ts=3:sw=3

from random import Random
from Globals import DTMLFile, InitializeClass
from Globals import Persistent
from OFS.Folder import Folder


manage_addRandomFolderForm = DTMLFile('addRandomFolder', globals())


class RandomFolder(Persistent, Folder):
   """ RandomFolder based on OFS.Folder.
   """
   meta_type = 'Random Folder'

   _properties = Folder._properties + (
         { 'id':'behaviour', 'type':'string', 'mode':'w' },
         ) 

   def __init__(self, id, title=''):
      self.rand  = Random()
      self.title = title
      self._setProperty('behaviour', 'redirect') # Use redirects by default
      Folder.__init__(self, id)
      
   def index_html(self, REQUEST, RESPONSE):
      """ Selects a random item from the folder and returns it.
      """
      if len(self) == 0:
         return 'no items'
      behaviour = self.getProperty('behaviour')

      if (behaviour == 'redirect'):
         # Perform a redirect to the URL of the (randomly choosed) real item.
         RESPONSE.redirect(self.absolute_url() + '/' + self.rand.choice(self.objectIds()))
      else:
         # Return the (randomly choosed) real item directly.
         RESPONSE.setHeader('Cache-Control', 'no-cache')
         RESPONSE.setHeader('Pragma', 'no-cache')
         RESPONSE.setHeader('Expires', '-1')
         return self.rand.choice(self.objectValues()).index_html(REQUEST, RESPONSE)



def manage_addRandomFolder(ctx, id, title='', REQUEST=None):
   """ Adds a new RandomFolder object with id *id*.
   """
   id = str(id)
   ctx._setObject(id, RandomFolder(id, str(title)))
   if REQUEST is not None:
      return ctx.manage_main(ctx, REQUEST, update_menu=1)


InitializeClass(RandomFolder)

